Module advice

Module advice 

Structs

AdviceInputs
Inputs container to initialize advice provider for the execution of Miden VM programs.
AdviceMap
Defines a set of non-deterministic (advice) inputs which the VM can access by their keys.
AdviceProvider
An advice provider is a component through which the VM can request nondeterministic inputs from the host (i.e., result of a computation performed outside of the VM), as well as insert new data into the advice provider to be recovered by the host after the program has finished executing.
AdviceStack
Advice stack values ordered from top to bottom.

Enums

AdviceError
AdviceMutation
Any possible way an event can modify the advice provider.

Constants

MAX_ADVICE_STACK_SIZE
Maximum number of elements allowed on the advice stack. Set to 2^17.