Module miden_processor::crypto

source ·

Structs

  • 192-bit output blake3 hasher.
  • 256-bit output blake3 hasher.
  • A merkle path container, composed of a sequence of nodes of a Merkle tree.
  • An in-memory data store for Merkelized data.
  • A fully-balanced binary Merkle tree (i.e., a tree where the number of leaves is a power of two).
  • Implementation of the Rescue Prime Optimized hash function with 256-bit output.
  • A simplified version of the SPONGE_PRG reseedable pseudo-random number generator algorithm described in https://eprint.iacr.org/2011/499.pdf. The simplification is related to to the following facts:
  • A sparse Merkle tree with 64-bit keys and 4-element leaf values, without compaction.
  • Pseudo-random element generator for finite fields, which is a default implementation of the RandomCoin trait.

Enums

Traits

  • Defines a cryptographic hash function for hashing field elements.
  • Defines a cryptographic hash function.
  • Pseudo-random element generator for finite fields.