Struct SecretKey
pub struct SecretKey { /* private fields */ }Expand description
Secret key for EdDSA (Ed25519) signature verification over Curve25519.
Implementations
impl SecretKey
impl SecretKey
pub fn public_key(&self) -> PublicKey
pub fn public_key(&self) -> PublicKey
Gets the corresponding public key for this secret key.
Computes a Diffie-Hellman shared secret from this secret key and the ephemeral public key generated by the other party.