pub struct SigningKey(/* private fields */);Expand description
A secret key for EdDSA (Ed25519) signature verification over Curve25519.
Implementations
Sourceimpl SigningKey
impl SigningKey
Sourcepub fn new() -> SigningKey
pub fn new() -> SigningKey
Generates a new random signing key using the OS random number generator.
This is cryptographically secure as long as rand::rng remains so.
Sourcepub fn with_rng<R>(rng: &mut R) -> SigningKey
pub fn with_rng<R>(rng: &mut R) -> SigningKey
Generates a new secret key using RNG.
Sourcepub fn public_key(&self) -> PublicKey
pub fn public_key(&self) -> PublicKey
Gets the corresponding public key for this secret key.