Struct InnerNodeInfo
pub struct InnerNodeInfo {
pub value: Word,
pub left: Word,
pub right: Word,
}Expand description
Representation of a node with two children used for iterating over containers.
Fields
value: Wordleft: Wordright: WordTrait Implementations
impl Clone for InnerNodeInfo
impl Clone for InnerNodeInfo
fn clone(&self) -> InnerNodeInfo
fn clone(&self) -> InnerNodeInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for InnerNodeInfo
impl Debug for InnerNodeInfo
impl<'de> Deserialize<'de> for InnerNodeInfo
impl<'de> Deserialize<'de> for InnerNodeInfo
fn deserialize<__D>(
__deserializer: __D,
) -> Result<InnerNodeInfo, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<InnerNodeInfo, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Extend<InnerNodeInfo> for MerkleStore
impl Extend<InnerNodeInfo> for MerkleStore
fn extend<I>(&mut self, iter: I)where
I: IntoIterator<Item = InnerNodeInfo>,
fn extend<I>(&mut self, iter: I)where
I: IntoIterator<Item = InnerNodeInfo>,
Extends a collection with the contents of an iterator. Read more
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
🔬This is a nightly-only experimental API. (
extend_one)Extends a collection with exactly one element.
Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
🔬This is a nightly-only experimental API. (
extend_one)Reserves capacity in a collection for the given number of additional elements. Read more
impl FromIterator<InnerNodeInfo> for MerkleStore
impl FromIterator<InnerNodeInfo> for MerkleStore
fn from_iter<I>(iter: I) -> MerkleStorewhere
I: IntoIterator<Item = InnerNodeInfo>,
fn from_iter<I>(iter: I) -> MerkleStorewhere
I: IntoIterator<Item = InnerNodeInfo>,
Creates a value from an iterator. Read more
impl PartialEq for InnerNodeInfo
impl PartialEq for InnerNodeInfo
impl Serialize for InnerNodeInfo
impl Serialize for InnerNodeInfo
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for InnerNodeInfo
impl StructuralPartialEq for InnerNodeInfo