Struct miden_processor::crypto::RpoRandomCoin
source · pub struct RpoRandomCoin { /* private fields */ }Expand description
A simplified version of the SPONGE_PRG reseedable pseudo-random number generator algorithm
described in https://eprint.iacr.org/2011/499.pdf. The simplification is related to
to the following facts:
- A call to the reseed method implies one and only one call to the permutation function. This is possible because in our case we never reseed with more than 4 field elements.
- As a result of the previous point, we dont make use of an input buffer to accumulate seed
material.
It is important to note that the current implementation of
RPORandomCoinassumes thatdraw_integers()is called immediately afterreseed_with_int().