Module trace_state

Module trace_state 

Structs

AdviceReplay
Implements a shim for the advice provider, in which all advice provider operations during a given fragment are pre-recorded by the fast processor.
BlockStackReplay
Replay data for the block stack.
CoreTraceState
Subset of the processor state used to build the core trace (system, decoder and stack sets of columns).
DecoderState
The subset of the decoder state required to build the trace.
ExecutionContextSystemInfo
Data required to recover the state of an execution context when restoring it during an END operation.
ExecutionReplay
Replay data necessary to build a trace fragment.
ExternalNodeReplay
HasherReplay
Implements a shim for the hasher chiplet, in which all hasher operations during a given fragment are pre-recorded by the fast processor.
MemoryReplay
Implements a shim for the memory chiplet, in which all elements read from memory during a given fragment are recorded by the fast processor, and replayed by the main trace fragment generators.
NodeEndData
The data needed to fully recover the state on an END operation.
NodeFlags
The flags written in the second word of the hasher state for END operations.
StackOverflowReplay
Implements a shim for stack overflow operations, in which all overflow values and addresses during a given fragment are pre-recorded by the fast processor and replayed by the main trace fragment generators.
StackState
This struct captures the state of the top 16 elements of the stack at a specific clock cycle; that is, those elements that are written directly into the trace.
SystemState
The SystemState represents all the information needed to build one row of the System trace.
TraceFragmentContext
Information required to build a trace fragment of length super::NUM_ROWS_PER_CORE_FRAGMENT.

Enums

NodeExecutionState
Specifies the execution state of a node.