pub trait TwoAdicField: Field {
const TWO_ADICITY: usize;
// Required method
fn two_adic_generator(bits: usize) -> Self;
}Expand description
A field which supplies information like the two-adicity of its multiplicative group, and methods for obtaining two-adic generators.
Required Associated Constants
Sourceconst TWO_ADICITY: usize
const TWO_ADICITY: usize
The number of factors of two in this field’s multiplicative group.
Required Methods
Sourcefn two_adic_generator(bits: usize) -> Self
fn two_adic_generator(bits: usize) -> Self
Returns a generator of the multiplicative group of order 2^bits.
Assumes bits <= TWO_ADICITY, otherwise the result is undefined.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".