execute

Function execute 

pub async fn execute(
    program: &Program,
    stack_inputs: StackInputs,
    advice_inputs: AdviceInputs,
    host: &mut impl Host,
    options: ExecutionOptions,
) -> Result<ExecutionOutput, ExecutionError>
Executes the provided program against the provided inputs and returns the resulting execution output.

The host parameter is used to provide the external environment to the program being executed, such as access to the advice provider and libraries that the program depends on.

Errors

Returns an error if program execution fails for any reason.