Struct BasicBlockNodeParams
pub struct BasicBlockNodeParams {
pub max_ops_len: usize,
pub max_pairs: usize,
pub max_decorator_id_u32: u32,
}Expand description
Parameters for generating BasicBlockNode instances
Fields
max_ops_len: usizeMaximum number of operations in a generated basic block
max_pairs: usizeMaximum number of decorator pairs in a generated basic block
max_decorator_id_u32: u32Maximum value for decorator IDs (u32)