Struct CallNode
pub struct CallNode { /* private fields */ }Expand description
A Call node describes a function call such that the callee is executed in a different execution context from the currently executing code.
A call node can be of two types:
- A simple call: the callee is executed in the new user context.
- A syscall: the callee is executed in the root context.
Implementations
impl CallNode
Constants
impl CallNode
Constants
pub const CALL_DOMAIN: Felt
pub const CALL_DOMAIN: Felt
The domain of the call block (used for control block hashing).
pub const SYSCALL_DOMAIN: Felt
pub const SYSCALL_DOMAIN: Felt
The domain of the syscall block (used for control block hashing).
impl CallNode
Public accessors
impl CallNode
Public accessors
pub fn callee(&self) -> MastNodeId
pub fn callee(&self) -> MastNodeId
Returns the ID of the node to be invoked by this call node.
pub fn is_syscall(&self) -> bool
pub fn is_syscall(&self) -> bool
Returns true if this call node represents a syscall.