Struct DebugVarId
pub struct DebugVarId(/* private fields */);Expand description
An identifier for a debug variable stored in DebugInfo.
This is analogous to DecoratorId but specifically for debug variable information.
Implementations
impl DebugVarId
impl DebugVarId
pub fn from_u32_bounded(
value: u32,
bound: usize,
) -> Result<DebugVarId, DeserializationError>
pub fn from_u32_bounded( value: u32, bound: usize, ) -> Result<DebugVarId, DeserializationError>
Returns a new DebugVarId with the provided inner value, or an error if the provided
value is greater than or equal to bound.