Struct DecoratorId
pub struct DecoratorId(/* private fields */);Expand description
An opaque handle to a Decorator in some MastForest. It is the responsibility of the user
to use a given DecoratorId with the corresponding MastForest.
Implementations
impl DecoratorId
impl DecoratorId
pub fn from_u32_safe(
value: u32,
mast_forest: &MastForest,
) -> Result<DecoratorId, DeserializationError>
pub fn from_u32_safe( value: u32, mast_forest: &MastForest, ) -> Result<DecoratorId, DeserializationError>
Returns a new DecoratorId with the provided inner value, or an error if the provided
value is greater than the number of nodes in the forest.
For use in deserialization.
pub fn from_u32_bounded(
value: u32,
bound: usize,
) -> Result<DecoratorId, DeserializationError>
pub fn from_u32_bounded( value: u32, bound: usize, ) -> Result<DecoratorId, DeserializationError>
Returns a new DecoratorId with the provided inner value, or an error if the provided
value is greater than or equal to bound.
For use in deserialization when the bound is known without needing the full MastForest.