pub struct DenseMastForestBuilder { /* private fields */ }Expand description
Construction surface for dense MAST forests.
The builder may append nodes while a forest is under construction. The value returned by
Self::finish is a finalized MastForest in final dense order: external nodes sorted by
digest, then basic blocks in construction order, then internal nodes with children before
parents and construction order as the tie-breaker.
Implementations
Sourceimpl DenseMastForestBuilder
impl DenseMastForestBuilder
Sourcepub fn new() -> DenseMastForestBuilder
pub fn new() -> DenseMastForestBuilder
Returns an empty dense MAST forest builder.
Sourcepub fn push_node(
&mut self,
builder: impl Into<MastNodeBuilder>,
) -> Result<MastNodeId, MastForestError>
pub fn push_node( &mut self, builder: impl Into<MastNodeBuilder>, ) -> Result<MastNodeId, MastForestError>
Adds a node builder to this forest and returns its builder-local node ID.
Sourcepub fn get_node_by_id(&self, node_id: MastNodeId) -> Option<&MastNode>
pub fn get_node_by_id(&self, node_id: MastNodeId) -> Option<&MastNode>
Returns a node by its builder-local node ID.
Sourcepub fn mark_root(&mut self, root: MastNodeId)
pub fn mark_root(&mut self, root: MastNodeId)
Marks a builder-local node ID as a procedure root.
Panics
Panics if root does not identify a node already added to this builder.
Sourcepub fn finish(self) -> Result<MastForest, MastForestError>
pub fn finish(self) -> Result<MastForest, MastForestError>
Finalizes this builder into a dense MastForest.
Sourcepub fn finish_with_id_map(
self,
) -> Result<(MastForest, DenseIdMap<MastNodeId, MastNodeId>), MastForestError>
pub fn finish_with_id_map( self, ) -> Result<(MastForest, DenseIdMap<MastNodeId, MastNodeId>), MastForestError>
Finalizes this builder and returns the builder-local to final node ID map.