Struct MastForestRootMap
pub struct MastForestRootMap { /* private fields */ }Expand description
A mapping for the new location of the roots of a MastForest after a merge.
It maps the roots (MastNodeIds) of a forest to their new MastNodeId in the merged
forest. See MastForest::merge for more details.
Implementations
impl MastForestRootMap
impl MastForestRootMap
pub fn map_root(
&self,
forest_index: usize,
root: &MastNodeId,
) -> Option<MastNodeId>
pub fn map_root( &self, forest_index: usize, root: &MastNodeId, ) -> Option<MastNodeId>
Maps the given root to its new location in the merged forest, if such a mapping exists.
It is guaranteed that every root of the map’s corresponding forest is contained in the map.