pub struct MastNodeFingerprint { /* private fields */ }Expand description
Represents the hash used to test for equality between crate::mast::MastNodes.
The decorator root will be None if and only if there are no decorators attached to the node,
and all children have no decorator roots (meaning that there are no decorators in all the
descendants).
Implementations
Sourceimpl MastNodeFingerprint
Constructors
impl MastNodeFingerprint
Constructors
Sourcepub fn new(mast_root: Word) -> MastNodeFingerprint
pub fn new(mast_root: Word) -> MastNodeFingerprint
Creates a new MastNodeFingerprint from the given MAST root with an empty decorator root.
Sourcepub fn with_decorator_root(
mast_root: Word,
decorator_root: Digest<32>,
) -> MastNodeFingerprint
pub fn with_decorator_root( mast_root: Word, decorator_root: Digest<32>, ) -> MastNodeFingerprint
Creates a new MastNodeFingerprint from the given MAST root and the given
DecoratorFingerprint.
Sourceimpl MastNodeFingerprint
Augmentation
impl MastNodeFingerprint
Augmentation
Sourcepub fn augment_with_data(self, data: &[u8]) -> MastNodeFingerprint
pub fn augment_with_data(self, data: &[u8]) -> MastNodeFingerprint
Returns a new fingerprint that incorporates the given additional data into the decorator root hash.
This is used by the assembler to make the dedup key sensitive to external metadata
without storing that metadata on the node builder.
If data is empty, the fingerprint is returned unchanged.