Enum DebugOptions
pub enum DebugOptions {
StackAll,
StackTop(u8),
MemAll,
MemInterval(u32, u32),
LocalInterval(u16, u16, u16),
AdvStackTop(u16),
}Expand description
Options of the Debug decorator.
These options define the debug info which gets printed out when the Debug decorator is executed.
Variants
StackAll
Print out the entire contents of the stack for the current execution context.
StackTop(u8)
Prints out the top n items of the stack for the current context.
MemAll
Prints out the entire contents of RAM.
MemInterval(u32, u32)
Prints out the contents of memory stored in the provided interval. Interval boundaries are both inclusive.
First parameter specifies the interval starting address, second – the ending address.
LocalInterval(u16, u16, u16)
Prints out locals stored in the provided interval of the currently executing procedure. Interval boundaries are both inclusive.
First parameter specifies the starting address, second – the ending address, and the third specifies the overall number of locals.
AdvStackTop(u16)
Prints out the top n items of the advice stack for the current context.
If n = 0, the entire stack is printed.