Struct AssemblyOp
pub struct AssemblyOp { /* private fields */ }Expand description
Contains information corresponding to an assembly instruction (only applicable in debug mode).
Implementations
impl AssemblyOp
impl AssemblyOp
pub fn new(
location: Option<Location>,
context_name: String,
num_cycles: u8,
op: String,
) -> AssemblyOp
pub fn new( location: Option<Location>, context_name: String, num_cycles: u8, op: String, ) -> AssemblyOp
Returns AssemblyOp instantiated with the specified assembly instruction string and number of cycles it takes to execute the assembly instruction.
pub fn context_name(&self) -> &str
pub fn context_name(&self) -> &str
Returns the context name for this operation.
pub const fn num_cycles(&self) -> u8
pub const fn num_cycles(&self) -> u8
Returns the number of VM cycles taken to execute the assembly instruction of this decorator.
pub fn set_num_cycles(&mut self, num_cycles: u8)
pub fn set_num_cycles(&mut self, num_cycles: u8)
Change cycles corresponding to an AsmOp decorator to the specified number of cycles.
pub fn set_location(&mut self, location: Location)
pub fn set_location(&mut self, location: Location)
Change the [Location] of this AssemblyOp