Struct DebugVarInfo
pub struct DebugVarInfo { /* private fields */ }Expand description
Debug information for tracking a source-level variable.
This decorator provides debuggers with information about where a variable’s value can be found at a particular point in the program execution.
Implementations
impl DebugVarInfo
impl DebugVarInfo
pub fn new(
name: impl Into<Arc<str>>,
value_location: DebugVarLocation,
) -> DebugVarInfo
pub fn new( name: impl Into<Arc<str>>, value_location: DebugVarLocation, ) -> DebugVarInfo
Creates a new DebugVarInfo with the specified variable name and location.
pub fn set_type_id(&mut self, type_id: u32)
pub fn set_type_id(&mut self, type_id: u32)
Sets the type ID for this variable.
pub fn arg_index(&self) -> Option<NonZero<u32>>
pub fn arg_index(&self) -> Option<NonZero<u32>>
Returns the argument index if this is a function parameter. The index is 1-based.
pub fn set_arg_index(&mut self, arg_index: u32)
pub fn set_arg_index(&mut self, arg_index: u32)
Sets the argument index for this variable.
Panics
Panics if arg_index is 0, since argument indices are 1-based.
pub fn location(&self) -> Option<&FileLineCol>
pub fn location(&self) -> Option<&FileLineCol>
Returns the source location if set. This is only set when the location differs from the AssemblyOp decorator location.
pub fn set_location(&mut self, location: FileLineCol)
pub fn set_location(&mut self, location: FileLineCol)
Sets the source location for this variable. Only set this when the location differs from the AssemblyOp decorator location to avoid package bloat.
pub fn value_location(&self) -> &DebugVarLocation
pub fn value_location(&self) -> &DebugVarLocation
Returns where the variable’s value can be found.