Module serde

Module serde 

Structs

BudgetedReader
A reader wrapper that enforces a byte budget during deserialization.
SliceReader
Implements ByteReader trait for a slice of bytes.

Enums

DeserializationError
Defines errors which can occur during deserialization.

Traits

ByteReader
Defines how primitive values are to be read from Self.
ByteWriter
Defines how primitive values are to be written into Self.
Deserializable
Defines how to deserialize Self from bytes.
Serializable
Defines how to serialize Self into bytes.

Functions

read_bounded_len
Reads and validates a serialized length before it is used for allocation.
validate_bounded_len
Validates that a serialized length fits both the reader budget and remaining input.