pub struct AsmOpInfo { /* private fields */ }
Contains assembly instruction and operation index in the sequence corresponding to the specified AsmOp decorator. This index starts from 1 instead of 0.

Implementations

Returns AsmOpInfo instantiated with the specified assembly instruction string, number of cycles it takes to execute the assembly instruction and op index in sequence of operations corresponding to the current assembly instruction. The first index is 1 instead of 0.

Returns the assembly instruction corresponding to this state.

Returns the gerneralized form of assembly instruction corresponding to this state.

Returns the number of VM cycles taken to execute the assembly instruction.

Returns the operation index of the operation at the specified clock cycle in the sequence of operations corresponding to the current assembly instruction.