pub struct TraceCollector { /* private fields */ }Expand description
A debug handler that collects and counts trace events from decorators.
Implementations
Sourceimpl TraceCollector
impl TraceCollector
Sourcepub fn get_trace_count(&self, trace_id: u32) -> u32
pub fn get_trace_count(&self, trace_id: u32) -> u32
Gets the count of executions for a specific trace ID.
Sourcepub fn get_execution_order(&self) -> &[(u32, u64)]
pub fn get_execution_order(&self) -> &[(u32, u64)]
Gets the execution order as a reference.