pub struct TraceLenSummary { /* private fields */ }
Contains the data about lengths of the trace parts.

  • main_trace_len contains the length of the main trace.
  • range_trace_len contains the length of the range checker trace.
  • chiplets_trace_len contains the trace lengths of the all chiplets (hash, bitwise, memory, kernel ROM)

Implementations

source

impl TraceLenSummary

source

pub fn new( main_trace_len: usize, range_trace_len: usize, chiplets_trace_len: ChipletsLengths ) -> Self

source

pub fn main_trace_len(&self) -> usize

Returns length of the main trace

source

pub fn range_trace_len(&self) -> usize

Returns length of the range table

source

pub fn chiplets_trace_len(&self) -> ChipletsLengths

Returns ChipletsLengths which contains trace lengths of all chilplets.

source

pub fn trace_len(&self) -> usize

Returns the maximum of all component lengths.

source

pub fn padded_trace_len(&self) -> usize

Returns trace_len rounded up to the next power of two.