Chiplets

Struct Chiplets 

pub struct Chiplets {
    pub hasher: Hasher,
    pub bitwise: Bitwise,
    pub memory: Memory,
    pub ace: Ace,
    pub kernel_rom: KernelRom,
}
This module manages the VM’s hasher, bitwise, memory, arithmetic circuit evaluation (ACE) and kernel ROM chiplets and is responsible for building a final execution trace from their stacked execution traces and chiplet selectors.

The module’s trace can be thought of as 6 stacked segments in the following form:

  • Hasher segment: contains the trace and selector for the hasher chiplet. This segment fills the first rows of the trace up to the length of the hasher trace_len.

    • column 0: selector column with values set to ZERO
    • columns 1-16: execution trace of hash chiplet
    • columns 17-20: unused columns padded with ZERO
  • Bitwise segment: contains the trace and selectors for the bitwise chiplet. This segment begins at the end of the hasher segment and fills the next rows of the trace for the trace_len of the bitwise chiplet.

    • column 0: selector column with values set to ONE
    • column 1: selector column with values set to ZERO
    • columns 2-14: execution trace of bitwise chiplet
    • columns 15-20: unused columns padded with ZERO
  • Memory segment: contains the trace and selectors for the memory chiplet. This segment begins at the end of the bitwise segment and fills the next rows of the trace for the trace_len of the memory chiplet.

    • column 0-1: selector columns with values set to ONE
    • column 2: selector column with values set to ZERO
    • columns 3-17: execution trace of memory chiplet
    • columns 18-20: unused columns padded with ZERO
  • ACE segment: contains the trace and selectors for the arithmetic circuit evaluation chiplet. This segment begins at the end of the memory segment and fills the next rows of the trace for the trace_len of the ACE chiplet.

    • column 0-2: selector columns with values set to ONE
    • column 3: selector column with values set to ZERO
    • columns 4-20: execution trace of ACE chiplet
  • Kernel ROM segment: contains the trace and selectors for the kernel ROM chiplet * This segment begins at the end of the memory segment and fills the next rows of the trace for the trace_len of the kernel ROM chiplet.

    • column 0-3: selector columns with values set to ONE
    • column 4: selector column with values set to ZERO
    • columns 5-9: execution trace of kernel ROM chiplet
    • columns 10-20: unused column padded with ZERO
  • Padding segment: unused. This segment begins at the end of the kernel ROM segment and fills the rest of the execution trace minus the number of random rows. When it finishes, the execution trace should have exactly enough rows remaining for the specified number of random rows.

    • columns 0-4: selector columns with values set to ONE
    • columns 5-20: unused columns padded with ZERO

The following is a pictorial representation of the chiplet module:

            +---+--------------------------------------------------------------+------+
            | 0 |                                                              |------|
            | . |         Hash chiplet                                         |------|
            | . |         16 columns                                           |------|
            | . |       constraint degree 8                                    |------|
            | 0 |                                                              |------|
            +---+---+------------------------------------------------------+---+------+
            | 1 | 0 |                                                      |----------|
            | . | . |                  Bitwise chiplet                     |----------|
            | . | . |                    13 columns                        |----------|
            | . | . |               constraint degree 5                    |----------|
            | . | . |                                                      |----------|
            | . | 0 |                                                      |----------|
            | . +---+---+--------------------------------------------------+-----+----+
            | . | 1 | 0 |                                                        |----|
            | . | . | . |            Memory chiplet                              |----|
            | . | . | . |              15 columns                                |----|
            | . | . | . |          constraint degree 9                           |----|
            | . | . | 0 |                                                        |----|
            | . + . +---+---+----------------------------------------------------+----+
            | . | . | 1 | 0 |                                                         |
            | . | . | . | . |          ACE chiplet                                    |
            | . | . | . | . |            16 columns                                   |
            | . | . | . | . |        constraint degree 5                              |
            | . | . | . | 0 |                                                         |
            | . + . | . +---+---+---------------------------+-------------------------+
            | . | . | . | 1 | 0 |                           |-------------------------|
            | . | . | . | . | . |     Kernel ROM chiplet    |-------------------------|
            | . | . | . | . | . |     5 columns             |-------------------------|
            | . | . | . | . | . |     constraint degree 9   |-------------------------|
            | . | . | . | . | 0 |                           |-------------------------|
            | . + . | . | . +---+---+-----------------------+-------------------------+
            | . | . | . | . | 1 | 0 |-------------------------------------------------|
            | . | . | . | . | . | . |-------------------------------------------------|
            | . | . | . | . | . | . |-------------------------------------------------|
            | . | . | . | . | . | . |-------------------------------------------------|
            | . | . | . | . | . | . |-------------------- Padding --------------------|
            | . + . | . | . | . | . |-------------------------------------------------|
            | . | . | . | . | . | . |-------------------------------------------------|
            | . | . | . | . | . | . |-------------------------------------------------|
            | . | . | . | . | . | . |-------------------------------------------------|
            | 1 | 1 | 1 | 1 | 1 | 0 |-------------------------------------------------|
            +---+---+---+---+---------------------------------------------------------+

Fields

hasher: Hasherbitwise: Bitwisememory: Memoryace: Acekernel_rom: KernelRom

Implementations

Source

impl Chiplets

pub fn new(kernel: Kernel) -> Self

Returns a new Chiplets component instantiated with the provided Kernel.

pub fn trace_len(&self) -> usize

Returns the length of the trace required to accommodate chiplet components and 1 mandatory padding row required for ensuring sufficient trace length for auxiliary connector columns that rely on the memory chiplet.

pub fn bitwise_start(&self) -> RowIndex

Returns the index of the first row of Bitwise execution trace.

pub fn memory_start(&self) -> RowIndex

Returns the index of the first row of the Memory execution trace.

pub fn ace_start(&self) -> RowIndex

Returns the index of the first row of KernelRom execution trace.

pub fn kernel_rom_start(&self) -> RowIndex

Returns the index of the first row of KernelRom execution trace.

pub fn padding_start(&self) -> RowIndex

Returns the index of the first row of the padding section of the execution trace.

pub fn append_range_checks(&self, range_checker: &mut RangeChecker)

Adds all range checks required by the memory chiplet to the provided `RangeChecker`` instance.

pub fn into_trace(self, trace_len: usize) -> ChipletsTrace

Returns an execution trace of the chiplets containing the stacked traces of the Hasher, Bitwise, ACE, Memory chiplets, and kernel ROM chiplet.