ExecutionTrace

Struct ExecutionTrace 

pub struct ExecutionTrace { /* private fields */ }
Execution trace which is generated when a program is executed on the VM.

The trace consists of the following components:

  • Main traces of System, Decoder, Operand Stack, Range Checker, and Chiplets.
  • Auxiliary trace builders.
  • Information about the program (program hash and the kernel).
  • Information about execution outputs (stack state, deferred precompile requests, and the final precompile transcript).
  • Summary of trace lengths of the main trace components.

Implementations

Source

impl ExecutionTrace

pub fn program_info(&self) -> &ProgramInfo

Returns the program info of this execution trace.

pub fn program_hash(&self) -> &Word

Returns hash of the program execution of which resulted in this execution trace.

pub fn stack_outputs(&self) -> &StackOutputs

Returns outputs of the program execution which resulted in this execution trace.

pub fn public_inputs(&self) -> PublicInputs

Returns the public inputs for this execution trace.

pub fn to_public_values(&self) -> Vec<Felt>

Returns the public values for this execution trace.

pub fn aux_trace_builders(&self) -> AuxTraceBuilders

Returns a clone of the auxiliary trace builders.

pub fn main_trace(&self) -> &MainTrace

Returns a reference to the main trace.

pub fn main_trace_mut(&mut self) -> &mut MainTrace

Returns a mutable reference to the main trace.

pub fn precompile_requests(&self) -> &[PrecompileRequest]

Returns the precompile requests generated during program execution.

pub fn final_precompile_transcript(&self) -> PrecompileTranscript

Returns the final precompile transcript observed during execution.

pub fn precompile_transcript_digest(&self) -> PrecompileTranscriptDigest

Returns the digest of the final precompile transcript observed during execution.

pub fn into_outputs( self, ) -> (StackOutputs, Vec<PrecompileRequest>, PrecompileTranscript)

Returns the owned execution outputs required for proof packaging.

pub fn init_stack_state(&self) -> StackInputs

Returns the initial state of the top 16 stack registers.

pub fn last_stack_state(&self) -> StackOutputs

Returns the final state of the top 16 stack registers.

pub fn get_user_op_helpers_at(&self, clk: u32) -> [Felt; 6]

Returns helper registers state at the specified clk of the VM

pub fn get_trace_len(&self) -> usize

Returns the trace length.

pub fn length(&self) -> usize

Returns the length of the trace (number of rows in the main trace).

pub fn trace_len_summary(&self) -> &TraceLenSummary

Returns a summary of the lengths of main, range and chiplet traces.

pub fn check_constraints(&self)

Validates this execution trace against all AIR constraints without generating a STARK proof.

This is the recommended way to test trace correctness. It is much faster than full STARK proving and provides better error diagnostics (panics on the first constraint violation with the instance and row index).

Panics

Panics if any AIR constraint evaluates to nonzero.

pub fn to_row_major_matrix(&self) -> RowMajorMatrix<Felt>

Returns the main trace as a row-major matrix for proving.

Only includes the first [TRACE_WIDTH] columns (excluding padding columns added for Poseidon2 rate alignment), which is the width expected by the AIR.

pub fn print(&self)

pub fn get_column_range(&self, range: Range<usize>) -> Vec<Vec<Felt>>

pub fn build_aux_trace<E>(&self, rand_elements: &[E]) -> Option<ColMatrix<E>>
where E: ExtensionField<Felt>,