pub struct TraceGenerationContext {
pub core_trace_contexts: Vec<CoreTraceFragmentContext>,
pub range_checker_replay: RangeCheckerReplay,
pub memory_writes: MemoryWritesReplay,
pub bitwise_replay: BitwiseReplay,
pub hasher_for_chiplet: HasherRequestReplay,
pub kernel_replay: KernelReplay,
pub ace_replay: AceReplay,
pub fragment_size: usize,
}Fields
core_trace_contexts: Vec<CoreTraceFragmentContext>The list of trace fragment contexts built during execution.
range_checker_replay: RangeCheckerReplaymemory_writes: MemoryWritesReplaybitwise_replay: BitwiseReplayhasher_for_chiplet: HasherRequestReplaykernel_replay: KernelReplayace_replay: AceReplayfragment_size: usizeThe number of rows per core trace fragment, except for the last fragment which may be shorter.