pub struct TraceLenSummary { /* private fields */ }Expand description
Contains the data about lengths of the trace parts.
main_trace_lencontains the length of the main trace.range_trace_lencontains the length of the range checker trace.chiplets_trace_lencontains the trace lengths of the all chiplets (hash, bitwise, memory, kernel ROM)
Implementations
Sourceimpl TraceLenSummary
impl TraceLenSummary
pub fn new( main_trace_len: usize, range_trace_len: usize, chiplets_trace_len: ChipletsLengths, ) -> Self
Sourcepub fn main_trace_len(&self) -> usize
pub fn main_trace_len(&self) -> usize
Returns length of the main trace.
Sourcepub fn range_trace_len(&self) -> usize
pub fn range_trace_len(&self) -> usize
Returns length of the range checker trace.
Sourcepub fn chiplets_trace_len(&self) -> ChipletsLengths
pub fn chiplets_trace_len(&self) -> ChipletsLengths
Returns ChipletsLengths which contains trace lengths of all chilplets.
Sourcepub fn padded_trace_len(&self) -> usize
pub fn padded_trace_len(&self) -> usize
Returns trace_len rounded up to the next power of two, clamped to MIN_TRACE_LEN.
Sourcepub fn padding_percentage(&self) -> usize
pub fn padding_percentage(&self) -> usize
Returns the percent (0 - 100) of the steps that were added to the trace to pad it to the next power of tow.