Struct miden_processor::utils::collections::RecordingMap
pub struct RecordingMap<K, V> { /* private fields */ }Expand description
A RecordingMap that records read requests to the underlying key-value map.
The data recorder is used to generate a proof for read requests.
The RecordingMap is composed of three parts:
data: which contains the current set of key-value pairs in the map.updates: which tracks keys for which values have been since the map was instantiated. updates include both insertions and updates of values under existing keys.trace: which contains the key-value pairs from the original data which have been accesses since the map was instantiated.
Implementations
impl<K, V> RecordingMap<K, V>where
K: Ord + Clone,
V: Clone,
impl<K, V> RecordingMap<K, V>where K: Ord + Clone, V: Clone,
pub fn new(init: impl IntoIterator<Item = (K, V)>) -> RecordingMap<K, V>
pub fn new(init: impl IntoIterator<Item = (K, V)>) -> RecordingMap<K, V>
Returns a new RecordingMap instance initialized with the provided key-value pairs. (BTreeMap).
pub fn into_proof(self) -> BTreeMap<K, V, Global>
pub fn into_proof(self) -> BTreeMap<K, V, Global>
Consumes the RecordingMap and returns a BTreeMap containing the key-value pairs from the initial data set that were read during recording.