pub trait ApplyDiff<K, V>
where K: Ord + Clone, V: Clone,
{ type DiffType; // Required method fn apply(&mut self, diff: Self::DiffType); }
A trait for applying the difference between two objects.

Required Associated Types

type DiffType

The type that describes the difference between two objects.

Required Methods

fn apply(&mut self, diff: Self::DiffType)

Applies the provided changes described by Self::DiffType to the object implementing this trait.

Implementors



impl<K, V, T> ApplyDiff<K, V> for T
where K: Ord + Clone, V: Clone, T: KvMap<K, V>,



type DiffType = KvMapDiff<K, V>