pub trait Diff<K, V>
where K: Ord + Clone, V: Clone,
{ type DiffType; // Required method fn diff(&self, other: &Self) -> Self::DiffType; }
A trait for computing the difference between two objects.

Required Associated Types

type DiffType

The type that describes the difference between two objects.

Required Methods

fn diff(&self, other: &Self) -> Self::DiffType

Returns a Self::DiffType object that represents the difference between this object and other.

Object Safety

This trait is not object safe.

Implementors



impl<K, V, T> Diff<K, V> for T
where K: Ord + Clone, V: Clone + PartialEq, T: KvMap<K, V>,



type DiffType = KvMapDiff<K, V>