uninit_vector

Function uninit_vector 

pub fn uninit_vector<T>(length: usize) -> Vec<MaybeUninit<T>>
Returns a vector of the specified length with un-initialized memory.

This is usually faster than requesting a vector with initialized memory and is useful when we overwrite all contents of the vector immediately after memory allocation.