Crate miden_processor

Crate miden_processor 

Re-exports

pub use trace::ExecutionWitness;
pub use trace::VmWitness;

Modules

advice
crypto
event
field
mast
MAST forest: a collection of procedures represented as Merkle trees.
operation
serde
trace
utils

Structs

AceError
ContextId
Represents the ID of an execution context
DefaultHost
A default SyncHost implementation that provides the essential functionality required by the VM.
ExecutionClaim
The external statement a Miden VM proof attests: the program root and kernel identify the executed code and its syscall authorization set; the stack inputs and outputs are the execution’s public I/O.
ExecutionOptions
A set of parameters specifying execution parameters of the VM.
ExecutionOutput
The output of a program execution, containing the state of the stack, advice provider, memory, and final deferred state at the end of execution.
FastProcessor
A fast processor which doesn’t generate any trace.
Felt
A Felt backed by Plonky3’s Goldilocks field element.
HostLibrary
A rich library representing a MastForest which also exports a list of handlers for events it may call.
KernelDescriptor
A list of exported kernel procedure hashes defining a VM kernel.
LoadedMastForest
Executable MAST loaded by the host, together with the package debug info that belongs to the same forest.
MemMastForestStore
A simple MastForestStore where all known MastForests are held in memory.
MemoryAddress
PackageSourceDebugContext
Source-occurrence debug context decoded from package debug sections.
PrecompileWitness
A hydrated witness for one or more ordered deferred precompile roots.
ProcessorState
A view into the current state of the processor.
Program
An executable program for Miden VM.
ProgramInfo
A program information set consisting of its MAST root and set of kernel procedure roots used for its compilation.
ResumeContext
The context required to resume execution of a program from the last point at which it was stopped.
SourceInlineCallContext
Package-owned source context whose inline-call rows remain active across a dynamic target.
StackInputs
Defines the initial state of the VM’s operand stack.
StackOutputs
Defines the final state of the VM’s operand stack at the end of program execution.
StdoutWriter
A wrapper that implements fmt::Write for stdout when the std feature is enabled.
Word
A unit of data consisting of 4 field elements.

Enums

BreakReason
The reason why execution was interrupted.
Continuation
Represents a unit of work in the continuation stack.
ExecutionError
ExecutionOptionsError
HostError
Error type for host-related operations.
InputError
MemoryError
Lightweight error type for memory operations.

Constants

EMPTY_WORD
Array of field elements representing word of ZEROs in the Miden base field.
MIN_STACK_DEPTH
Represents:
ONE
Field element representing ONE in the Miden base field.
WORD_SIZE
The number of field elements in a Miden word.
ZERO
Field element representing ZERO in the Miden base field.

Traits

BaseHost
Defines the host functionality shared by both sync and async execution.
FutureMaybeSend
Alias for a Future
Host
Defines an async interface by which the VM can interact with the host during execution.
MastForestStore
A set of MastForests available to the prover that programs may refer to (by means of an miden_core::mast::ExternalNode).
ProgramExecutor
A pluggable program executor used to run a Program against a Host.
Stopper
A trait for types that determine whether execution should be stopped after each clock cycle.
SyncHost
Defines a synchronous interface by which the VM can interact with the host during execution.

Functions

advice_error_with_package_source_context
Wraps an AdviceError with package-owned source-occurrence execution context.
event_error_with_package_source_context
Wraps an EventError with package-owned source-occurrence execution context.
format_value
Formats a value as a string, using “EMPTY” for None values.
procedure_not_found_with_package_source_context
Creates a ProcedureNotFound error with package-owned source-occurrence execution context.
write_interval
Writes a generic interval with proper alignment and optional remaining count.
write_stack
Writes a stack-like list of elements (operand or advice stack) in the VM’s debug format.