Re-exports
pub use trace::TraceBuildInputs;pub use trace::TraceGenerationContext;
Modules
- advice
- crypto
- event
- field
- mast
- MAST forest: a collection of procedures represented as Merkle trees.
- operation
- precompile
- Precompile framework for deferred verification in the Miden VM.
- serde
- trace
- utils
Structs
- AceError
- Context
Id - Represents the ID of an execution context
- Default
Host - A default SyncHost implementation that provides the essential functionality required by the VM.
- Execution
Options - A set of parameters specifying execution parameters of the VM.
- Execution
Output - The output of a program execution, containing the state of the stack, advice provider, memory, and final precompile transcript at the end of execution.
- Fast
Processor - A fast processor which doesn’t generate any trace.
- Felt
- A
Feltbacked by Plonky3’s Goldilocks field element. - Host
Library - A rich library representing a
MastForestwhich also exports a list of handlers for events it may call. - Kernel
- A list of exported kernel procedure hashes defining a VM kernel.
- Loaded
Mast Forest - Executable MAST loaded by the host, together with the package debug info that belongs to the same forest.
- MemMast
Forest Store - A simple
MastForestStorewhere all knownMastForests are held in memory. - Memory
Address - Package
Source Debug Context - Source-occurrence debug context decoded from package debug sections.
- Processor
State - A view into the current state of the processor.
- Program
- An executable program for Miden VM.
- Program
Info - A program information set consisting of its MAST root and set of kernel procedure roots used for its compilation.
- Resume
Context - The context required to resume execution of a program from the last point at which it was stopped.
- Stack
Inputs - Defines the initial state of the VM’s operand stack.
- Stack
Outputs - Defines the final state of the VM’s operand stack at the end of program execution.
- Stdout
Writer - A wrapper that implements
fmt::Writeforstdoutwhen thestdfeature is enabled. - Word
- A unit of data consisting of 4 field elements.
Enums
- Break
Reason - The reason why execution was interrupted.
- Continuation
- Represents a unit of work in the continuation stack.
- Execution
Error - Execution
Options Error - Host
Error - Error type for host-related operations.
- Input
Error - Memory
Error - Lightweight error type for memory operations.
Constants
- EMPTY_
WORD - Array of field elements representing word of ZEROs in the Miden base field.
- MIN_
STACK_ DEPTH - Represents:
- ONE
- Field element representing ONE in the Miden base field.
- WORD_
SIZE - The number of field elements in a Miden word.
- ZERO
- Field element representing ZERO in the Miden base field.
Traits
- Base
Host - Defines the host functionality shared by both sync and async execution.
- Future
Maybe Send - Alias for a
Future - Host
- Defines an async interface by which the VM can interact with the host during execution.
- Mast
Forest Store - A set of
MastForests available to the prover that programs may refer to (by means of anmiden_core::mast::ExternalNode). - Stopper
- A trait for types that determine whether execution should be stopped after each clock cycle.
- Sync
Host - Defines a synchronous interface by which the VM can interact with the host during execution.
Functions
- advice_
error_ with_ package_ source_ context - Wraps an
AdviceErrorwith package-owned source-occurrence execution context. - event_
error_ with_ package_ source_ context - Wraps an
EventErrorwith package-owned source-occurrence execution context. - execute
- Executes the provided program against the provided inputs and returns the resulting execution output.
- execute_
sync - Synchronous wrapper for the async
execute()function. - format_
value - Formats a value as a string, using “EMPTY” for None values.
- procedure_
not_ found_ with_ package_ source_ context - Creates a
ProcedureNotFounderror with package-owned source-occurrence execution context. - write_
interval - Writes a generic interval with proper alignment and optional remaining count.
- write_
stack - Writes a stack-like list of elements (operand or advice stack) in the VM’s debug format.