Crate miden_processor
source · [−]Structs
Contains assembly instruction and operation index in the sequence corresponding to the specified AsmOp decorator. This index starts from 1 instead of 0.
Execution trace which is generated when a program is executed on the VM.
A program which can be executed by the VM.
Input container for Miden VM programs.
VmState holds a current process state information at a specific clock cycle.
Iterator that iterates through vm state at each step of the execution. This allows debugging or replaying ability to view various process state at each clock cycle. If the execution returned an error, it returns that error on the clock cycle it stopped.
Enums
Constants
Functions
Returns an execution trace resulting from executing the provided program against the provided inputs.
Returns an iterator that allows callers to step through each execution and inspect vm state information along side.
Type Definitions
Output type of Rescue Prime hash function.