pub enum Continuation {
Show 13 variants
StartNode(MastNodeId),
FinishJoin(MastNodeId),
FinishSplit(MastNodeId),
FinishLoop {
node_id: MastNodeId,
was_entered: bool,
},
FinishCall(MastNodeId),
FinishDyn(MastNodeId),
FinishExternal(MastNodeId),
ResumeBasicBlock {
node_id: MastNodeId,
batch_index: usize,
op_idx_in_batch: usize,
},
Respan {
node_id: MastNodeId,
batch_index: usize,
},
FinishBasicBlock(MastNodeId),
EnterForest(Arc<MastForest>),
AfterExitDecorators(MastNodeId),
AfterExitDecoratorsBasicBlock(MastNodeId),
}Expand description
Represents a unit of work in the continuation stack.
This enum defines the different types of continuations that can be performed on MAST nodes during program execution.
Variants
StartNode(MastNodeId)
Start processing a node in the MAST forest.
FinishJoin(MastNodeId)
Process the finish phase of a Join node.
FinishSplit(MastNodeId)
Process the finish phase of a Split node.
FinishLoop
Process the finish phase of a Loop node.
The was_entered field indicates whether the loop body was entered at least once. When
was_entered == false, the loop condition was ZERO and the loop body was never executed.
FinishCall(MastNodeId)
Process the finish phase of a Call node.
FinishDyn(MastNodeId)
Process the finish phase of a Dyn node.
FinishExternal(MastNodeId)
Process the finish phase of an External node (execute after_exit decorators).
ResumeBasicBlock
Resume execution at the specified operation of the specified batch in the given basic block node.
Respan
Resume execution at the RESPAN operation before the specific batch within a basic block node.
FinishBasicBlock(MastNodeId)
Process the finish phase of a basic block node.
This corresponds to incrementing the clock to account for the inserted END operation, and
then executing AfterExitDecoratorsBasicBlock.
EnterForest(Arc<MastForest>)
Enter a new MAST forest, where all subsequent MastNodeIds will be relative to this forest.
When we encounter an ExternalNode, we enter the corresponding MAST forest directly, and
push an EnterForest continuation to restore the previous forest when done.
AfterExitDecorators(MastNodeId)
Process the after_exit decorators of the given node.
AfterExitDecoratorsBasicBlock(MastNodeId)
Process the after_exit decorators of the basic block node.
Similar to AfterExitDecorators, but also executes all operation-level decorators that
refer to after the last operation in the basic block. See
miden_core::mast::BasicBlockNode for more details.
Implementations
Sourceimpl Continuation
impl Continuation
Sourcepub fn increments_clk(&self) -> bool
pub fn increments_clk(&self) -> bool
Returns true if executing this continuation increments the processor clock, and false otherwise.