Skip to main contentModule event
Source - EventHandlerRegistry
- Registry for maintaining event handlers.
- EventId
- A type-safe event identifier that semantically represents a
Felt value. - EventName
- A human-readable name for an event.
- NoopEventHandler
- A handler which ignores the process state and leaves the
AdviceProvider unchanged. - TraceHandlerRegistry
- Registry for maintaining trace handlers.
- SystemEvent
- Defines a set of host-side actions which can be initiated from the VM.
- EventHandler
- An
EventHandler defines a function that that can be called from the processor which can
read the VM state and modify the state of the advice provider. - TraceHandler
- Handles an optional, read-only trace event emitted by the VM.
- EventError
- A generic
Error wrapper allowing handlers to return errors to the Host caller. - TraceError
- Error type returned by trace handlers.