Implements a shim for the memory chiplet, in which all elements read from memory during a given
fragment are recorded by the fast processor, and replayed by the main trace fragment generators.
Implements a shim for stack overflow operations, in which all overflow values and addresses
during a given fragment are pre-recorded by the fast processor and replayed by the main trace
fragment generators.
This struct captures the state of the top 16 elements of the stack at a specific clock cycle;
that is, those elements that are written directly into the trace.