Struct MastNodeId
pub struct MastNodeId(/* private fields */);Expand description
An opaque handle to a MastNode in some MastForest. It is the responsibility of the user
to use a given MastNodeId with the corresponding MastForest.
Note that the MastForest does not ensure that equal MastNodes have equal
MastNodeId handles. Hence, MastNodeId equality must not be used to test for equality of
the underlying MastNode.
Implementations
impl MastNodeId
impl MastNodeId
pub fn from_u32_safe(
value: u32,
mast_forest: &MastForest,
) -> Result<MastNodeId, DeserializationError>
pub fn from_u32_safe( value: u32, mast_forest: &MastForest, ) -> Result<MastNodeId, DeserializationError>
Returns a new MastNodeId with the provided inner value, or an error if the provided
value is greater than the number of nodes in the forest.
For use in deserialization.
pub fn from_usize_safe(
node_id: usize,
mast_forest: &MastForest,
) -> Result<MastNodeId, DeserializationError>
pub fn from_usize_safe( node_id: usize, mast_forest: &MastForest, ) -> Result<MastNodeId, DeserializationError>
Returns a new MastNodeId with the provided node_id, or an error if node_id is
greater than the number of nodes in the MastForest for which this ID is being
constructed.
pub fn new_unchecked(value: u32) -> MastNodeId
pub fn new_unchecked(value: u32) -> MastNodeId
Returns a new MastNodeId from the given value without checking its validity.
pub fn remap(&self, remapping: &BTreeMap<MastNodeId, MastNodeId>) -> MastNodeId
pub fn remap(&self, remapping: &BTreeMap<MastNodeId, MastNodeId>) -> MastNodeId
Remap the NodeId to its new position using the given Remapping.