Module operation

Module operation 

Structs

AssemblyOp
Contains information corresponding to an assembly instruction (only applicable in debug mode).
DebugVarInfo
Debug information for tracking a source-level variable.

Enums

DebugOptions
Options of the Debug decorator.
DebugVarLocation
Describes where a variable’s value can be found during execution.
Decorator
A set of decorators which can be executed by the VM.
Operation
A set of native VM operations which take exactly one cycle to execute.
OperationError
Lightweight error type for operations that can fail.

Constants

OPCODE_ADD
OPCODE_ADVPOP
OPCODE_ADVPOPW
OPCODE_AND
OPCODE_ASSERT
OPCODE_CALL
OPCODE_CALLER
OPCODE_CLK
OPCODE_CRYPTOSTREAM
OPCODE_CSWAP
OPCODE_CSWAPW
OPCODE_DROP
OPCODE_DUP0
OPCODE_DUP1
OPCODE_DUP2
OPCODE_DUP3
OPCODE_DUP4
OPCODE_DUP5
OPCODE_DUP6
OPCODE_DUP7
OPCODE_DUP9
OPCODE_DUP11
OPCODE_DUP13
OPCODE_DUP15
OPCODE_DYN
OPCODE_DYNCALL
OPCODE_EMIT
OPCODE_END
OPCODE_EQ
OPCODE_EQZ
OPCODE_EVALCIRCUIT
OPCODE_EXPACC
OPCODE_EXT2MUL
OPCODE_FRIE2F4
OPCODE_HALT
OPCODE_HORNERBASE
OPCODE_HORNEREXT
OPCODE_HPERM
OPCODE_INCR
OPCODE_INV
OPCODE_JOIN
OPCODE_LOGPRECOMPILE
OPCODE_LOOP
OPCODE_MLOAD
OPCODE_MLOADW
OPCODE_MOVDN2
OPCODE_MOVDN3
OPCODE_MOVDN4
OPCODE_MOVDN5
OPCODE_MOVDN6
OPCODE_MOVDN7
OPCODE_MOVDN8
OPCODE_MOVUP2
OPCODE_MOVUP3
OPCODE_MOVUP4
OPCODE_MOVUP5
OPCODE_MOVUP6
OPCODE_MOVUP7
OPCODE_MOVUP8
OPCODE_MPVERIFY
OPCODE_MRUPDATE
OPCODE_MSTORE
OPCODE_MSTOREW
OPCODE_MSTREAM
OPCODE_MUL
OPCODE_NEG
OPCODE_NOOP
OPCODE_NOT
OPCODE_OR
OPCODE_PAD
OPCODE_PIPE
OPCODE_PUSH
OPCODE_REPEAT
OPCODE_RESPAN
OPCODE_SDEPTH
OPCODE_SPAN
OPCODE_SPLIT
OPCODE_SWAP
OPCODE_SWAPDW
OPCODE_SWAPW
OPCODE_SWAPW2
OPCODE_SWAPW3
OPCODE_SYSCALL
OPCODE_U32ADD
OPCODE_U32ADD3
OPCODE_U32AND
OPCODE_U32ASSERT2
OPCODE_U32DIV
OPCODE_U32MADD
OPCODE_U32MUL
OPCODE_U32SPLIT
OPCODE_U32SUB
OPCODE_U32XOR

Type Aliases

DecoratorList
Vector consisting of a tuple of operation index (within a span block) and decorator at that index.