Module chiplets

Module chiplets 

Structs

Ace
Arithmetic circuit evaluation (ACE) chiplet.
Chiplets
This module manages the VM’s hasher, bitwise, memory, arithmetic circuit evaluation (ACE) and kernel ROM chiplets and is responsible for building a final execution trace from their stacked execution traces and chiplet selectors.
ChipletsTrace
CircuitEvaluation
Contains the variable and evaluation nodes resulting from the evaluation of a circuit. The output value is checked to be equal to 0.
MerkleRootUpdate
Result of a Merkle tree node update.
Poseidon2PermutationTrace

Constants

MAX_EVAL_CIRCUIT_INVOCATIONS
Maximum number of eval_circuit invocations recorded in an execution witness.
MAX_EVAL_CIRCUIT_WIRES
Maximum combined number of READ and EVAL wires accepted by one eval_circuit operation.
MAX_NUM_ACE_WIRES
PTR_OFFSET_ELEM
PTR_OFFSET_WORD