pub struct ExecutionTrace { /* private fields */ }Expand description
Execution trace which is generated when a program is executed on the VM.
The trace consists of the following components:
- Per-AIR trace matrices for Core, Chiplets, and Poseidon2Permutation.
- Information about the program (program hash and the kernel).
- Information about execution outputs (stack state and final deferred state).
- Summary of trace lengths of the main trace components.
Implementations
Sourceimpl ExecutionTrace
impl ExecutionTrace
Sourcepub fn program_info(&self) -> &ProgramInfo
pub fn program_info(&self) -> &ProgramInfo
Returns the program info of this execution trace.
Sourcepub fn program_hash(&self) -> &Word
pub fn program_hash(&self) -> &Word
Returns hash of the program execution of which resulted in this execution trace.
Sourcepub fn stack_outputs(&self) -> &StackOutputs
pub fn stack_outputs(&self) -> &StackOutputs
Returns outputs of the program execution which resulted in this execution trace.
Sourcepub fn public_inputs(&self) -> PublicInputs
pub fn public_inputs(&self) -> PublicInputs
Returns the public inputs for this execution trace.
Sourcepub fn to_public_values(&self) -> Vec<Felt>
pub fn to_public_values(&self) -> Vec<Felt>
Returns the public values for this execution trace.
Sourcepub fn main_trace(&self) -> &MainTrace
pub fn main_trace(&self) -> &MainTrace
Returns a reference to the main trace.
Sourcepub fn main_trace_mut(&mut self) -> &mut MainTrace
pub fn main_trace_mut(&mut self) -> &mut MainTrace
Returns a mutable reference to the main trace.
Sourcepub fn deferred_state(&self) -> &DeferredState
pub fn deferred_state(&self) -> &DeferredState
Returns the final deferred state generated during program execution.
Sourcepub fn into_outputs(self) -> StackOutputs
pub fn into_outputs(self) -> StackOutputs
Returns the owned stack outputs required for proof packaging.
Sourcepub fn init_stack_state(&self) -> StackInputs
pub fn init_stack_state(&self) -> StackInputs
Returns the initial state of the top 16 stack registers.
Sourcepub fn last_stack_state(&self) -> StackOutputs
pub fn last_stack_state(&self) -> StackOutputs
Returns the final state of the top 16 stack registers.
Sourcepub fn get_user_op_helpers_at(&self, clk: u32) -> [Felt; 6]
pub fn get_user_op_helpers_at(&self, clk: u32) -> [Felt; 6]
Returns helper registers state at the specified clk of the VM
Sourcepub fn get_trace_len(&self) -> usize
pub fn get_trace_len(&self) -> usize
Returns the trace length.
Sourcepub fn length(&self) -> usize
pub fn length(&self) -> usize
Returns the length of the trace (number of rows in the main trace).
Sourcepub fn trace_len_summary(&self) -> &TraceLenSummary
pub fn trace_len_summary(&self) -> &TraceLenSummary
Returns a summary of the per-component trace lengths.
Sourcepub fn check_constraints(&self)
pub fn check_constraints(&self)
Validates this execution trace against all AIR constraints without generating a STARK proof.
This is the recommended way to test trace correctness. It is much faster than full STARK proving and provides better error diagnostics (panics on the first constraint violation with the instance and row index).
Panics
Panics if any AIR constraint evaluates to nonzero.
Sourcepub fn to_air_matrices(
&self,
) -> (RowMajorMatrix<Felt>, RowMajorMatrix<Felt>, RowMajorMatrix<Felt>)
pub fn to_air_matrices( &self, ) -> (RowMajorMatrix<Felt>, RowMajorMatrix<Felt>, RowMajorMatrix<Felt>)
Splits the trace into the per-AIR matrices consumed by the multi-AIR proving path.
Sourcepub fn into_air_matrices(
self,
) -> (RowMajorMatrix<Felt>, RowMajorMatrix<Felt>, RowMajorMatrix<Felt>)
pub fn into_air_matrices( self, ) -> (RowMajorMatrix<Felt>, RowMajorMatrix<Felt>, RowMajorMatrix<Felt>)
Consuming variant for the proving hot path.