Trait miden_processor::utils::collections::ApplyDiff
pub trait ApplyDiff<K, V>{
type DiffType;
// Required method
fn apply(&mut self, diff: Self::DiffType);
}Expand description
A trait for applying the difference between two objects.
Required Associated Types
type DiffType
type DiffType
The type that describes the difference between two objects.
Required Methods
fn apply(&mut self, diff: Self::DiffType)
fn apply(&mut self, diff: Self::DiffType)
Applies the provided changes described by Self::DiffType to the object implementing this trait.