Trait miden_processor::utils::collections::Diff
pub trait Diff<K, V>{
type DiffType;
// Required method
fn diff(&self, other: &Self) -> Self::DiffType;
}Expand description
A trait for computing the difference between two objects.
Required Associated Types
type DiffType
type DiffType
The type that describes the difference between two objects.
Required Methods
fn diff(&self, other: &Self) -> Self::DiffType
fn diff(&self, other: &Self) -> Self::DiffType
Returns a Self::DiffType object that represents the difference between this object and other.
Object Safety
This trait is not object safe.