Trait miden_processor::utils::collections::TryApplyDiff
pub trait TryApplyDiff<K, V>{
type DiffType;
type Error;
// Required method
fn try_apply(&mut self, diff: Self::DiffType) -> Result<(), Self::Error>;
}Expand description
A trait for applying the difference between two objects with the possibility of failure.
Required Associated Types
type DiffType
type DiffType
The type that describes the difference between two objects.
type Error
type Error
An error type that can be returned if the changes cannot be applied.